if __name__ == "__main__":  # pragma: no cover
    from .cli import main as _main

    _main()
